@@ -3,6 +3,8 @@
 #' Extract the medoid time series based on a distance measure.
 #'
 #' @export
+#' @importFrom methods as
+#' @importFrom rlang exprs
 #' @importFrom Matrix rowSums
 #'
 #' @param series The time series in one of the formats accepted by [tslist()].
@@ -11,7 +13,7 @@
 #' @param ids Integer vector indicating which of the `series` should be considered.
 #' @param distmat Optionally, a pre-computed cross-distance matrix of *all* `series`.
 #' @param ... Any extra parameters for the `distance` function that may be used.
-#' @template error-check
+#' @param error.check `r roxygen_error_check_param()`
 #'
 #' @details
 #'
@@ -42,24 +44,21 @@ pam_cent <- function(series, distance, ids = seq_along(series), distmat = NULL,
         if (missing(distance))
             distance <- attr(distmat, "method")
 
-        args <- list(
-            distmat = distmat,
-            series = series,
-            dist_args = dots,
-            distance = distance,
-            control = partitional_control(),
-            error.check = error.check
-        )
-
         if (is.null(distmat)) {
             if (is.null(distance))
                 stop("If 'distmat' is missing, 'distance' must be provided.")
 
-            args$distmat <- NULL
+            distmat <- Distmat$new(
+                series = series,
+                dist_args = dots,
+                distance = distance,
+                control = partitional_control(),
+                error.check = error.check
+            )
+        }
+        else {
+            distmat <- methods::as(distmat, "Distmat")
         }
-
-        # S4-Distmat.R
-        distmat <- do.call(Distmat$new, args, TRUE)
     }
 
     d <- distmat[ids, ids, drop = FALSE]
