@@ -62,7 +62,7 @@ pdc_configs <- function(type = c("preproc", "distance", "centroid"), ...,
     if (length(shared) > 0L && length(share.config) > 0L) {
         # careful, singular and plural below
         shared_cfg <- Map(shared, names(shared), f = function(shared_args, fun) {
-            cfg <- quoted_call(expand.grid, foo = fun, stringsAsFactors = FALSE, dots = shared_args)
+            cfg <- quoted_call(expand.grid, fun, stringsAsFactors = FALSE, dots = shared_args)
             names(cfg)[1L] <- type
             cfg
         })
@@ -86,7 +86,7 @@ pdc_configs <- function(type = c("preproc", "distance", "centroid"), ...,
             if (!is.list(config) || is.null(config_names))
                 stop("All parameters must be named lists.") # nocov
             cfg <- Map(config, config_names, f = function(config_args, fun) {
-                cfg <- quoted_call(expand.grid, foo = fun, stringsAsFactors = FALSE, dots = config_args)
+                cfg <- quoted_call(expand.grid, fun, stringsAsFactors = FALSE, dots = config_args)
                 names(cfg)[1L] <- type
                 cfg
             })
@@ -631,7 +631,7 @@ compare_clusterings <- function(series = NULL, types = c("p", "h", "f", "t"),
         export <- c("trace", "score.clus", "return.objects",
                     "dots",
                     "centroids_included",
-                    "check_consistency", "quoted_call", "enlist", "subset_dots", "get_from_callers",
+                    "check_consistency", "do_call", "quoted_call", "enlist", "subset_dots", "get_from_callers",
                     "setnames_inplace",
                     custom_preprocs, custom_centroids)
 
@@ -682,16 +682,17 @@ compare_clusterings <- function(series = NULL, types = c("p", "h", "f", "t"),
             })
 
             setnames_inplace(args, c("preproc", "dist", "cent"))
-            args <- do.call(tsclust_args, args, TRUE)
+            args <- do_call("tsclust_args", args)
 
             # ----------------------------------------------------------------------------------
             # controls for this configuration
             # ----------------------------------------------------------------------------------
 
-            control_fun <- match.fun(paste0(type, "_control"))
+            control_fun_name <- paste0(type, "_control")
+            control_fun <- match.fun(control_fun_name)
             control_args <- subset_dots(as.list(cfg), control_fun)
             control_args <- lapply(control_args, unlist, recursive = FALSE)
-            control <- do.call(control_fun, control_args, TRUE)
+            control <- do_call(control_fun_name, control_args)
 
             # ----------------------------------------------------------------------------------
             # get processed series
@@ -719,7 +720,7 @@ compare_clusterings <- function(series = NULL, types = c("p", "h", "f", "t"),
                 distance <- cfg$distance
                 dist_entry <- dist_entries[[distance]]
                 if (!check_consistency(dist_entry$names[1L], "dist"))
-                    do.call(proxy::pr_DB$set_entry, dist_entry, TRUE) # nocov
+                    do_call(proxy::pr_DB$set_entry, dist_entry) # nocov
             }
             else distance <- NULL # dummy
 
@@ -749,7 +750,7 @@ compare_clusterings <- function(series = NULL, types = c("p", "h", "f", "t"),
 
             if (centroid_char == "default") {
                 # do not specify centroid
-                tsc <- do.call(tsclust, this_args, TRUE)
+                tsc <- do_call("tsclust", this_args)
             }
             else if (type %in% c("partitional", "fuzzy") && centroid_char %in% centroids_included) {
                 # with included centroid
@@ -982,7 +983,8 @@ compare_clusterings <- function(series = NULL, types = c("p", "h", "f", "t"),
                                f = function(result, cols) {
                                    order_args <- as.list(result[cols])
                                    names(order_args) <- NULL
-                                   result[do.call(base::order, order_args, TRUE), , drop = FALSE]
+                                   base_order <- base::order
+                                   result[do_call("base_order", order_args), , drop = FALSE]
                                })
     # return results
     results
