@@ -48,3 +48,27 @@ expect_equal_slots <- function(current, target, slots = c("cluster", "centroids"
                      info = paste("slot =", object_slot))
     }
 }
+
+expect_known_rds <- function(object, path, ..., info = NULL, update = TRUE) {
+    file <- if (missing(path)) paste0("rds/", rlang::enexpr(object)) else path
+
+    if (!file.exists(file)) {
+        warning("Creating reference value", call. = FALSE)
+        saveRDS(object, file, version = 2)
+        succeed()
+    }
+    else {
+        ref_val <- readRDS(file)
+        comp <- compare(object, ref_val, ...)
+        if (update && !comp$equal) {
+            saveRDS(object, file, version = version)
+        }
+        expect(comp$equal,
+               sprintf("%s has changed from known value recorded in %s.\n%s",
+                       file,
+                       encodeString(file, quote = "'"),
+                       comp$message),
+               info = info)
+    }
+    invisible(object)
+}
